@@ -11,10 +11,10 @@ sub Game {
 	return bless $self, ref($class) || $class;
 }
 
-###sub gameloop {
-###	my ($self) = shift;
+sub gameloop {
+	my ($self) = shift;
 	### subclass responsability
-###}
+}
 
 
 1;
