@@ -11,11 +11,11 @@ sub SpriteExample {
 	$self->$app = shift;
 
 	my $image1 = new SDL::Surface(-name=>"./images/larrysprite1.jpg");
-	$self->{imagelibrary}->push{$image1};
+	$self->{imagelibrary}->push($image1);
 	my $image2 = new SDL::Surface(-name=>"./images/larrysprite2.jpg");
-	$self->{imagelibrary}->push{$image1};
+	$self->{imagelibrary}->push($image2);
 	my $image3 = new SDL::Surface(-name=>"./images/larrysprite3.jpg");
-	$self->{imagelibrary}->push{$image1};
+	$self->{imagelibrary}->push($image3);
 	$self->{screenrect} = new SDL::Rect -width => $self->{box}->{w}, -height => $self->{box}->{h};
 
 	return bless $self, ref($class) || $class;	
